@@ -1,4 +1,4 @@
-nComp = function(Sol, Ka=0, DH)
+nComp = function(Sol, Ka=0, DH) # Single point Sol, Multiple Dosing History -> Dose-to-Dose, Multiple Sol, With non-zero initial value
 {
   L = Sol$L
   Co = Sol$Co
