@@ -209,7 +209,9 @@ nlr = function(Fx, Data, pNames, IE, LB, UB, Error="A", ObjFx=ObjDef, SecNames,
 #    logk = e$nRec/2*log(1 + qf(conf.level, 1, e$nRec - 1)/(e$nRec - 1))
 #    logk = e$nRec/2*log(1 + qf(conf.level, 1, e$nRec - e$nPara)/(e$nRec - e$nPara))
     df2 = max(2, e$nRec - e$nPara)
-    logk = e$nRec/2*log(1 + qf(conf.level, 1, df2)/df2)
+#    logk = e$nRec/2*log(1 + qf(conf.level, 1, df2)/df2)
+    delp = max(1, e$npara - 2) # vs. intercept + additive variance only model
+    logk = e$nRec/2*log(1 + delp*qf(conf.level, delp, df2)/df2)
     logk = min(logk, log(2/(1 - conf.level))) # Pawitan p240 k = 20 -> p < 0.05
   }
 #  logk = ifelse(missing(k), q, log(k)) # If nRec > 60, this is OK.
